#ifndef _OBJCONVERTER_H
#define _OBJCONVERTER_H

#include <string>
#include <vector>

struct Vector3
{
	Vector3() {}
	Vector3(float _x, float _y, float _z): x(_x), y(_y), z(_z) {}

	float x, y, z;
};

typedef std::vector<Vector3> VertexArray;
typedef std::pair<float, float> Texcoord;

class ogzstream;

/** Converts obj format into objects readable by our format
*/
class ObjConverter
{
public:

	ObjConverter();

	bool Convert(const std::string &inputFilename, 
		         const std::string &outputFilename);
	// const std::string textureFilename) const;

	~ObjConverter();

protected:

	struct Geometry
	{
		Vector3 *mVertices;
		Vector3 *mNormals;
		Texcoord *mTexcoords;

		int mVertexCount;
		int mTexcoordCount;
	};

	void LoadShape(const VertexArray &faceVertices,
		           const VertexArray &faceNormals,
				   const std::vector<Texcoord> &faceTexcoords);

	void WriteGeometry(ogzstream &str, Geometry *geom);

	bool ReadFile(const std::string &inputFilename);
	bool WriteFile(const std::string &outputFilename);


	std::vector<Geometry *> mGeometry;

	int mNumShapes;
};



#endif
